@@ -104,11 +104,13 @@ dt_href = function(doc, ...){
 # g        : logical passed to the graphics argument of the menu function
 #' @importFrom selectr querySelectorAll
 #' @importFrom XML htmlParse xmlGetAttr xmlValue
+#' @importFrom RCurl getURL
 first_stage_selection = function(selection, g, iter){
-  domain = "http://cliflo.niwa.co.nz/pls/niwp/"
+  domain = "https://cliflo.niwa.co.nz/pls/niwp/"
   full_path = paste0(domain, "wgenf.choose_datatype?cat=cat1")
+  cert = system.file("CurlSSL/cacert.pem", package = "RCurl")
   
-  datatypes_xml = querySelectorAll(htmlParse(full_path),
+  datatypes_xml = querySelectorAll(htmlParse(getURL(full_path, cainfo = cert)),
                                    "table.header td.popup a.top")
   
   if (!is.na(selection) && selection > 9){
@@ -138,9 +140,12 @@ first_stage_selection = function(selection, g, iter){
 #' @importFrom selectr querySelectorAll
 #' @importFrom XML htmlParse xmlGetAttr xmlValue
 second_stage_selection = function(href_1, selection, dt_name, g){
-  domain = "http://cliflo.niwa.co.nz/pls/niwp/"
+  domain = "https://cliflo.niwa.co.nz/pls/niwp/"
   full_path = paste0(domain, href_1)
-  datatypes_xml = querySelectorAll(htmlParse(full_path), "a.dt")
+  cert = system.file("CurlSSL/cacert.pem", package = "RCurl")
+  
+  datatypes_xml = querySelectorAll(htmlParse(getURL(full_path, cainfo = cert)), 
+                                   "a.dt")
   
   if (is.na(selection)){
     gsub("\\n", "", gsub(" {2,}", "", dt_href(datatypes_xml, g, dt_name)))
@@ -202,14 +207,15 @@ choose_dt_options = function(datatype_name, datatype_options, g){
 option_selections = function(href_2, selection_check, selection_combo, 
                              dt_type, g){
   selection_check = unique(selection_check)
-  domain = "http://cliflo.niwa.co.nz/pls/niwp/"
+  domain = "https://cliflo.niwa.co.nz/pls/niwp/"
   full_path = paste0(domain, href_2)
-  dt_options_xml = querySelectorAll(htmlParse(full_path), 
+  cert = system.file("CurlSSL/cacert.pem", package = "RCurl")
+  dt_options_xml = querySelectorAll(htmlParse(getURL(full_path, cainfo = cert)), 
                                     "td.selected table tr td.selected")
-  dt_params_xml = querySelectorAll(htmlParse(full_path), 
+  dt_params_xml = querySelectorAll(htmlParse(getURL(full_path, cainfo = cert)), 
                                    "td.selected table tr td input")
   dt_param_values = xmlSApply(dt_params_xml, xmlGetAttr, "value")
-  dt_combo_xml = querySelectorAll(htmlParse(full_path), 
+  dt_combo_xml = querySelectorAll(htmlParse(getURL(full_path, cainfo = cert)), 
                                   "td.selected table tr td select option")
   
   if (length(dt_combo_xml) == 0)
@@ -277,7 +283,7 @@ option_selections = function(href_2, selection_check, selection_combo,
 #
 # object : a cfDatatype object
 # user   : a cfUser object
-#' @importFrom RCurl getCurlHandle getForm
+#' @importFrom RCurl getCurlHandle
 cf_update_dt = function(object, user = cf_user()){
   cookies = file.path(tempdir(), user@username)
   curl = getCurlHandle(followlocation = TRUE,
@@ -286,10 +292,11 @@ cf_update_dt = function(object, user = cf_user()){
                          paste("clifro", R.Version()$version.string),
                        cookiefile = cookies, 
                        cookiejar = cookies)
+  cert = system.file("CurlSSL/cacert.pem", package = "RCurl")
   
   all_dt_params = c(object@dt_param, unlist(object@dt_sel_option_params))
   
-  postForm("http://cliflo.niwa.co.nz/pls/niwp/wgenf.genform1_proc",
+  postForm("https://cliflo.niwa.co.nz/pls/niwp/wgenf.genform1_proc",
            cselect = "wgenf.genform1?fset=defdtype",
            auswahl = "wgenf.genform1?fset=defagent",
            agents = "",
@@ -310,7 +317,8 @@ cf_update_dt = function(object, user = cf_user()){
            cstn_id = "A",
            cdata_order = "DS",
            .params = all_dt_params,
-           curl = curl)
+           curl = curl,
+           .opts = list(cainfo = cert))
 }
 
 
@@ -327,7 +335,7 @@ cf_update_dt = function(object, user = cf_user()){
 #' create datatypes programatically if the tree menu nodes are known a priori 
 #' (see examples). This function uses the same nodes, check box and combo box 
 #' options as CliFlo and can be viewed at the 
-#' \href{http://cliflo.niwa.co.nz/pls/niwp/wgenf.choose_datatype?cat=cat1}{datatype selection page}.
+#' \href{https://cliflo.niwa.co.nz/pls/niwp/wgenf.choose_datatype?cat=cat1}{datatype selection page}.
 #' 
 #' @param select_1 a numeric vector of first node selections
 #' @param select_2 a numeric vector of second node selections
